#!/usr/bin/env python3

""" Armenian script converter

This scripts allows the user to convert between the latinized transliteration
of Armenian and the Armenian Script itself with (almost) simple rules.

Usage
-----
pieoffice armenian <text>
    ----------------------------------------------------------------
    | a 	 ա | b	    բ | g	 գ | d	    դ | e	 ե |
    | ye	 ե | z      զ | ee	 է | e'     ը | t'	 թ | 
    | zh	 ժ | i	    ի | l	 լ | x	    խ | c	 ծ | 
    | k 	 կ | h      հ | j	 ձ | g.     ղ | l.	 ղ |
    | ch.	 ճ | m      մ | y	 յ | n      ն | sh	 շ |
    | o 	 ո | ch     չ | p	 պ | jh     ջ | r.	 ռ | 
    | s	         ս | v	    վ | t        տ | r	    ր | c'	 ց |
    | w          ւ | p'     փ | k'       ք | o'     օ | f 	 ֆ |
    | u	         ու| ev     և | ?	 ՞ | .      ։ | .'	 ՝ |
    | ;          ՟ | ;'     ՛ | !	 ՜ | ``     « | ''	 » |
    ----------------------------------------------------------------

"""

def alpha_to_armenian(input):
    """ Converts text in Latin Alphabet to Armenian Script

    Each syllable should be separated by a sing dash, each word by a space.

    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Armenian Script

    Usage
    -----
    
    > alpha_to_armenian("<++>")
    + 

    """
    # print(input.translate(script))

    output = input

    output = output.replace("ye", "ե")
    output = output.replace("YE", "Ե")
    output = output.replace("Ye", "Ե")
    output = output.replace("ee", "է")
    output = output.replace("EE", "Է")
    output = output.replace("ev", "և")
    output = output.replace("e'", "ը")
    output = output.replace("E'", "Ը")

    output = output.replace("e", "ե")
    output = output.replace("E", "Ե")

    output = output.replace("zh", "ժ")
    output = output.replace("ch", "չ")
    output = output.replace("ch.", "ճ")
    output = output.replace("sh", "շ")
    output = output.replace("jh", "ջ")
    output = output.replace("ZH", "Ժ")
    output = output.replace("CH.", "Ճ")
    output = output.replace("SH", "Շ")
    output = output.replace("CH", "Չ")
    output = output.replace("JH", "Ջ")

    output = output.replace("t'", "թ")
    output = output.replace("p'", "փ")
    output = output.replace("k'", "ք")
    output = output.replace("o'", "օ")
    output = output.replace("c'", "ց")
    output = output.replace("P'", "Փ")
    output = output.replace("C'", "Ց")
    output = output.replace("K'", "Ք")
    output = output.replace("O'", "Օ")
    output = output.replace("T'", "Թ")

    output = output.replace("g.", "ղ")
    output = output.replace("l.", "ղ")
    output = output.replace("r.", "ռ")
    output = output.replace("V.", "Վ")
    output = output.replace("R.", "Ռ")
    output = output.replace("G.", "Ղ")


    output = output.replace("I", "Ի")
    output = output.replace("L", "Լ")
    output = output.replace("X", "Խ")
    output = output.replace("C", "Ծ")
    output = output.replace("K", "Կ")
    output = output.replace("J", "Ձ")
    output = output.replace("M", "Մ")
    output = output.replace("Y", "Յ")
    output = output.replace("N", "Ն")
    output = output.replace("O", "Ո")
    output = output.replace("P", "Պ")
    output = output.replace("S", "Ս")
    output = output.replace("T", "Տ")
    output = output.replace("R", "Ր")
    output = output.replace("W", "Ւ")
    output = output.replace("F", "Ֆ")
    output = output.replace("U", "Սւ")
    output = output.replace("a", "ա")
    output = output.replace("b", "բ")
    output = output.replace("g", "գ")
    output = output.replace("d", "դ")
    output = output.replace("z", "զ")
    output = output.replace("i", "ի")
    output = output.replace("l", "լ")
    output = output.replace("x", "խ")
    output = output.replace("c", "ծ")
    output = output.replace("k", "կ")
    output = output.replace("j", "ձ")
    output = output.replace("m", "մ")
    output = output.replace("y", "յ")
    output = output.replace("n", "ն")
    output = output.replace("o", "ո")
    output = output.replace("p", "պ")
    output = output.replace("s", "ս")
    output = output.replace("v", "վ")
    output = output.replace("t", "տ")
    output = output.replace("r", "ր")
    output = output.replace("w", "ւ")
    output = output.replace("f", "ֆ")
    output = output.replace("u", "ու")
    output = output.replace("A", "Ա")
    output = output.replace("B", "Բ")
    output = output.replace("G", "Գ")
    output = output.replace("D", "Դ")
    output = output.replace("Z", "Զ")

    output = output.replace("h", "հ")
    output = output.replace("H", "Հ")


    output = output.replace("?", "՞")
    output = output.replace(".", "։")
    output = output.replace(".'", "՝")
    output = output.replace(";", "՟")
    output = output.replace(";'", "՛")
    output = output.replace("!", "՜")
    output = output.replace("``", "«")
    output = output.replace("''", "»")

    return output


if __name__ == "__main__":
       a = """
       Erkneer erkin erkneer erkir
       Erkneer ev covn cirani
       Erkn i covown owneer
       zkarmirkn el.egnik

       E'nd el.egan p'ol. cowx elaneer
       E'nd el.egan p'ol. boc' elaneer
       Ew i boc'oyn vazeer
       Xarteash patanekik

       na howr her owneer
       boc' owneer mawrows
       Ew achk'ownk'n eein aregakownk'
       """
       b = alpha_to_armenian(a)
       print(b)



#! /usr/bin/env python3

""" Ogham script converter

If no optional argument is passed, the script converts to Ogham Script.
The typing scheme is as follows:

    | b           ᚁ | l           ᚂ | w           ᚃ | s           ᚄ 
    | n           ᚅ | j           ᚆ | h           ᚆ | d           ᚇ 
    | t           ᚈ | k           ᚉ | kw          ᚊ | c           ᚉ 
    | cw          ᚊ | m           ᚋ | g           ᚌ | gw          ᚍ 
    | S           ᚎ | r           ᚏ | a           ᚐ | o           ᚑ 
    | u           ᚒ | e           ᚓ | i           ᚔ | ,ear,       ᚕ 
    | ,or,        ᚖ | ,uilleann,  ᚗ | ,ifin,      ᚘ | ,eam,       ᚙ 
    | ,peith,     ᚚ | >           ᚛ | <           ᚜

"""

def alpha_to_ogham(input):
    output = input

    output = output.replace(",ear,", "ᚕ")
    output = output.replace(",or,", "ᚖ")
    output = output.replace(",uilleann,", "ᚗ")
    output = output.replace(",ifin,", "ᚘ")
    output = output.replace(",eam,", "ᚙ")
    output = output.replace(",peith, ", "ᚚ")

    output = output.replace("b", "ᚁ")
    output = output.replace("l", "ᚂ")
    output = output.replace("w", "ᚃ")
    output = output.replace("s", "ᚄ")
    output = output.replace("n", "ᚅ")
    output = output.replace("j", "ᚆ")
    output = output.replace("h", "ᚆ")
    output = output.replace("d", "ᚇ")
    output = output.replace("t", "ᚈ")
    output = output.replace("kw ", "ᚊ")
    output = output.replace("k", "ᚉ")
    output = output.replace("cw ", "ᚊ")
    output = output.replace("c", "ᚉ")
    output = output.replace("m", "ᚋ")
    output = output.replace("gw ", "ᚍ")
    output = output.replace("g", "ᚌ")
    output = output.replace("S", "ᚎ")
    output = output.replace("r", "ᚏ")
    output = output.replace("a", "ᚐ")
    output = output.replace("o", "ᚑ")
    output = output.replace("u", "ᚒ")
    output = output.replace("e", "ᚓ")
    output = output.replace("i", "ᚔ")
    output = output.replace(">", "᚛")
    output = output.replace("<", "᚜")

    return output


if __name__ == "__main__":
       a = """
       >sean<
       >lielugnaedonmaccimenueh<
         """
       b = alpha_to_ogham(a)
       print(b)



#! /usr/bin/env python3

""" PIE converter

The transliteration scheme is close to the Harvard-Kyoto for Sanskrit:

      -----------------------------------------------
      | A	ā   |   I	 ī   |  U	ū   |
      | R	r̥   |   RR	 r̥̄   |  lR	l̥   |
      | lRR     l̥̄   |   A/	 ā́   |  I/	ī́   |
      | U/	ū́   |   R/       ŕ̥   |  RR/     r̥̄́   |
      | lR/     ĺ̥   |   lRR/     l̥̄́   |  c	k̑   |
      | cw	k̑ʷ  |   kw	 kʷ  |  j	ĝ   |
      | jw	gʷ  |   bh	 bʰ  |  dh	dʰ  |
      | jh	ĝʰ  |   gh	 gʰ  |  gw	gʷ  |
      | gwh     gʷʰ |   h1	 h₁  |  h2	h₂  |
      | h3	h₃  |   y	 i̯   |  w	u̯   |
      | E	ē   |   O	 ō   |  E/	ḗ   |
      | É	ḗ   |   O/	 ṓ   |  Ó	ṓ   |
      | M	m̥   |   N	 n̥   |              |
      -----------------------------------------------

"""

def alpha_to_pie(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Avestan Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("A/", "ā́")
    output = output.replace("A", "ā")
    output = output.replace("I/", "ī́")
    output = output.replace("I", "ī")
    output = output.replace("U/", "ū́")
    output = output.replace("U", "ū")
    output = output.replace("lRR/", "l̥̄́")
    output = output.replace("lRR", "l̥̄")
    output = output.replace("lR/", "ĺ̥")
    output = output.replace("lR", "l̥")
    output = output.replace("RR/", "r̥̄́")
    output = output.replace("RR", "r̥̄")
    output = output.replace("R/", "ŕ̥")
    output = output.replace("R", "r̥")
    output = output.replace("cw", "k̑ʷ")
    output = output.replace("c", "k̑")
    output = output.replace("kw", "kʷ")
    output = output.replace("jw", "ĝʷ")
    output = output.replace("j", "ĝ")
    output = output.replace("bh", "bʰ")
    output = output.replace("dh", "dʰ")
    output = output.replace("jh", "ĝʰ")
    output = output.replace("gh", "gʰ")
    output = output.replace("gw", "gʷ")
    output = output.replace("gwh", "gʷʰ")
    output = output.replace("h1", "h₁")
    output = output.replace("h2", "h₂")
    output = output.replace("h3", "h₃")
    output = output.replace("y", "i̯")
    output = output.replace("w", "u̯")
    output = output.replace("E/", "ḗ")
    output = output.replace("O", "ō")
    output = output.replace("É", "ḗ")
    output = output.replace("O/", "ṓ")
    output = output.replace("E", "ē")
    output = output.replace("Ó", "ṓ")
    output = output.replace("M", "m̥")
    output = output.replace("N", "n̥")
    return output


if __name__ == "__main__":
       a = """
       wókw-M
       """
       b = alpha_to_pie(a)
       print(b)



#! /usr/bin/env python3

""" Gothic converter

The transliteration scheme is as follows

    -----------------------------------------------------------------------
    | a     𐌰 | b     𐌱 | g     𐌲 | d     𐌳 | e     𐌴 | q     𐌵 | z     𐌶 |
    | h     𐌷 | th    𐌸 | i     𐌹 | k     𐌺 | l     𐌻 | m     𐌼 | n     𐌽 |
    | j     𐌾 | u     𐌿 | p     𐍀 | q'    𐍁 | r     𐍂 | s     𐍃 | t     𐍄 |
    | w     𐍅 | f     𐍆 | x     𐍇 | hw    𐍈 | o     𐍉 | z'    𐍊 |         |
    -----------------------------------------------------------------------

"""

def alpha_to_gothic(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Gothic Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("th", "𐌸")
    output = output.replace("q'", "𐍁")
    output = output.replace("z'", "𐍊")
    output = output.replace("hw", "𐍈")
    output = output.replace("a", "𐌰")
    output = output.replace("b", "𐌱")
    output = output.replace("g", "𐌲")
    output = output.replace("d", "𐌳")
    output = output.replace("e", "𐌴")
    output = output.replace("q", "𐌵")
    output = output.replace("z", "𐌶")
    output = output.replace("h", "𐌷")
    output = output.replace("i", "𐌹")
    output = output.replace("k", "𐌺")
    output = output.replace("l", "𐌻")
    output = output.replace("m", "𐌼")
    output = output.replace("n", "𐌽")
    output = output.replace("j", "𐌾")
    output = output.replace("u", "𐌿")
    output = output.replace("p", "𐍀")
    output = output.replace("r", "𐍂")
    output = output.replace("s", "𐍃")
    output = output.replace("t", "𐍄")
    output = output.replace("w", "𐍅")
    output = output.replace("f", "𐍆")
    output = output.replace("x", "𐍇")
    output = output.replace("o", "𐍉")
    

    return output


if __name__ == "__main__":
       a = """
       wulfila
       """
       b = alpha_to_gothic(a)
       print(b)



#!/usr/bin/env python3

"""PIE-Office: (Proto-)Indo-European Office

A terminal based script converter for ancient (Proto-)Indo-European languages.

Usage:
    pieoffice convert <language> [<text>]
    pieoffice rules <language>
    pieoffice list
    pieoffice --help

Languages:
    pie                 Proto-Indo-European
    linearb             Mycenaean Libear B
    cypriot             Cypriot Greek Script
    luwian              Hieroglyphic Luwian
    lycian              Lycian
    lydian              Lydian
    carian              Carian
    gothic              Gothic
    armenian            Armenian
    vedic               Vedic (HK>Devanagari)
    vedictranslit       Vedic (HK>IAST)
    avestan             Avestan (script)
    avestantranslit     Avestan (romanized)
    oldpersian          Old Persian Cuneiform
    ogham               Ogham Script
    oscan               Oscan (Old Italic Script)

Options:
    -h --help           Show this screen.

"""

from docopt import docopt

def main():
    arguments = docopt(__doc__)

    rules = False

    if arguments["convert"]:
        language = arguments["<language>"]
        if language == "pie":
            from pieoffice.pie import alpha_to_pie as conv
        if language == "linearb":
            from pieoffice.linearb import alpha_to_linearb as conv
        elif language == "luwian":
            from pieoffice.luwian import alpha_to_luwian as conv
        elif language == "lycian":
            from pieoffice.lycian import alpha_to_lycian as conv
        elif language == "lydian":
            from pieoffice.lydian import alpha_to_lydian as conv
        elif language == "carian":
            from pieoffice.carian import alpha_to_carian as conv
        elif language == "gothic":
            from pieoffice.gothic import alpha_to_gothic as conv
        elif language == "armenian":
            from pieoffice.armenian import alpha_to_armenian as conv
        elif language == "vedic":
            from pieoffice.vedic import hk_to_deva as conv
        elif language == "vedictranslit":
            from pieoffice.vedic import hk_to_iast as conv
        elif language == "avestan":
            from pieoffice.avestan import alpha_to_avestan as conv
        elif language == "avestantranslit":
            from pieoffice.avestan import alpha_to_avestan_trans as conv
        elif language == "oldpersian":
            from pieoffice.oldpersian import alpha_to_oldpersian as conv
        elif language == "ogham":
            from pieoffice.ogham import alpha_to_ogham as conv
        elif language == "oscan":
            from pieoffice.oscan import alpha_to_oscan as conv
        elif language == "cypriot":
            from pieoffice.cypriot import alpha_to_cypriot as conv


        if arguments['<text>']:
            print(conv(arguments['<text>']))
        else:
            print("Insert a text.")
            rules = True


    if arguments['rules'] or rules:
        language = arguments["<language>"]
        if language == "pie":
            from pieoffice.pie import __doc__ as doc
        if language == "linearb":
            from pieoffice.linearb import __doc__ as doc
        elif language == "luwian":
            from pieoffice.luwian import __doc__ as doc
        elif language == "lycian":
            from pieoffice.lycian import __doc__ as doc
        elif language == "lydian":
            from pieoffice.lydian import __doc__ as doc
        elif language == "carian":
            from pieoffice.carian import __doc__ as doc
        elif language == "gothic":
            from pieoffice.gothic import __doc__ as doc
        elif language == "armenian":
            from pieoffice.armenian import __doc__ as doc
        elif language == "avestan" or language == "avestantranslit":
            from pieoffice.avestan import __doc__ as doc
        elif language == "vedic" or language == "vedictranslit":
            from pieoffice.vedic import __doc__ as doc
        elif language == "oldpersian":
            from pieoffice.oldpersian import __doc__ as doc
        elif language == "ogham":
            from pieoffice.ogham import __doc__ as doc
        elif language == "oscan":
            from pieoffice.oscan import __doc__ as doc
        elif language == "cypriot":
            from pieoffice.cypriot import __doc__ as doc
        print(doc)

    if arguments['list']:
        print("""Languages:
            pie                 Proto-Indo-European
            linearb             Mycenaean Libear B
            cypriot             Cypriot Greek Script
            luwian              Hieroglyphic Luwian
            lycian              Lycian
            lydian              Lydian
            carian              Carian
            gothic              Gothic
            armenian            Armenian
            vedic               Vedic (HK>Devanagari)
            vedictranslit       Vedic (HK>IAST)
            avestan             Avestan (script)
            avestantranslit     Avestan (romanized)
            oldpersian          Old Persian Cuneiform
            ogham               Ogham Script
            oscan               Oscan (Old Italic Script)
            """
            )


if __name__ == "__main__":
    main()



#! /usr/bin/env python3

""" Cypriot script converter

If no optional argument is passed, the script converts to Cypriot Script.
The typing scheme is as follows:

-----------------------------------------------------------------------------
| a       𐠀   |   e       𐠁   |   i       𐠂   |    o       𐠃  |   u       𐠄 |
| wa      𐠲   |   we      𐠳   |   wi      𐠴   |    wo      𐠵  |             |
| za      𐠼   |               |               |    zo      𐠿  |             |
| ja      𐠅   |               |               |    jo      𐠈  |             |
| ka      𐠊   |   ke      𐠋   |   ki      𐠌   |    ko      𐠍  |   ku      𐠎 |
| la      𐠏   |   le      𐠐   |   li      𐠑   |    lo      𐠒  |   lu      𐠓 |
| ma      𐠔   |   me      𐠕   |   mi      𐠖   |    mo      𐠗  |   mu      𐠘 |
| na      𐠙   |   ne      𐠚   |   ni      𐠛   |    no      𐠜  |   nu      𐠝 |
| pa      𐠞   |   pe      𐠟   |   pi      𐠠   |    po      𐠡  |   pu      𐠢 |
| ra      𐠣   |   re      𐠤   |   ri      𐠥   |    ro      𐠦  |   ru      𐠧 |
| sa      𐠨   |   se      𐠩   |   si      𐠪   |    so      𐠫  |   su      𐠬 |
| ta      𐠭   |   te      𐠮   |   ti      𐠯   |    to      𐠰  |   tu      𐠱 |
| ksa     𐠷   |   kse     𐠸   |               |               |             |
-----------------------------------------------------------------------------

This conversion scheme supports Aegean numbers and measurements.

"""

from pieoffice.tools import get_key, aegean_numbers

def alpha_to_cypriot(input, numbers=True):
    output = input.replace("-","")

    output = output.replace("wa", "𐠲")
    output = output.replace("we", "𐠳")
    output = output.replace("wi", "𐠴")
    output = output.replace("wo", "𐠵")
    output = output.replace("za", "𐠼")
    output = output.replace("zo", "𐠿")
    output = output.replace("ja", "𐠅")
    output = output.replace("jo", "𐠈")
    output = output.replace("ka", "𐠊")
    output = output.replace("ke", "𐠋")
    output = output.replace("ki", "𐠌")
    output = output.replace("ko", "𐠍")
    output = output.replace("ku", "𐠎")
    output = output.replace("la", "𐠏")
    output = output.replace("le", "𐠐")
    output = output.replace("li", "𐠑")
    output = output.replace("lo", "𐠒")
    output = output.replace("lu", "𐠓")
    output = output.replace("ma", "𐠔")
    output = output.replace("me", "𐠕")
    output = output.replace("mi", "𐠖")
    output = output.replace("mo", "𐠗")
    output = output.replace("mu", "𐠘")
    output = output.replace("na", "𐠙")
    output = output.replace("ne", "𐠚")
    output = output.replace("ni", "𐠛")
    output = output.replace("no", "𐠜")
    output = output.replace("nu", "𐠝")
    output = output.replace("ksa", "𐠷")
    output = output.replace("kse", "𐠸")
    output = output.replace("pa", "𐠞")
    output = output.replace("pe", "𐠟")
    output = output.replace("pi", "𐠠")
    output = output.replace("po", "𐠡")
    output = output.replace("pu", "𐠢")
    output = output.replace("ra", "𐠣")
    output = output.replace("re", "𐠤")
    output = output.replace("ri", "𐠥")
    output = output.replace("ro", "𐠦")
    output = output.replace("ru", "𐠧")
    output = output.replace("sa", "𐠨")
    output = output.replace("se", "𐠩")
    output = output.replace("si", "𐠪")
    output = output.replace("so", "𐠫")
    output = output.replace("su", "𐠬")
    output = output.replace("ta", "𐠭")
    output = output.replace("te", "𐠮")
    output = output.replace("ti", "𐠯")
    output = output.replace("to", "𐠰")
    output = output.replace("tu", "𐠱")
    output = output.replace("a", "𐠀")
    output = output.replace("e", "𐠁")
    output = output.replace("i", "𐠂")
    output = output.replace("o", "𐠃")
    output = output.replace("u", "𐠄")

    output = output.replace("V", "𐄾")
    output = output.replace("M", "𐄸")
    output = output.replace("N", "𐄹")
    output = output.replace("T", "𐄼")
    output = output.replace("P", "𐄺")
    output = output.replace("Q", "𐄻")
    output = output.replace("L", "𐄷")
    output = output.replace("S", "𐄽")
    output = output.replace("Z", "𐄿")

    output = output.split()
    if numbers:
        for i in range(len(output)):
            if output[i].isnumeric():
                num_out = ""
                num = [int(j) for j in output[i]]
                tens = [10**n for n in range(len(num)-1,-1,-1)]
                for j in range(len(tens)):
                    num_out = num_out + aegean_numbers[str(num[j]*tens[j])]
                output[i] = num_out

    return " ".join(output)


if __name__ == "__main__":
       a = """
        si-se
        o-na-si-la-o 22 P
         """
       b = alpha_to_cypriot(a)
       print(b)



#! /usr/bin/env python3

""" Linear B Script converter

Glyphs with known syllabic values should be written in lower-case, syllabically
and numbered if +2. Glyphs with known logographic values should be written in
upper-case. The only exception for said rule are the gendered logograms, which
should be followed without space by a f or m. Glyphs with unknown value should
be written with an asterisk followed by the number (2 or 3 digits).

This conversion scheme supports Aegean numbers and measurements.

"""

from pieoffice.tools import get_key, aegean_numbers

def alpha_to_linearb(input, numbers=True):
    """ Converts text in Latin Alphabet to Linear B Script

    Each syllable should be separated by a sing dash, each word by a space.

    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Linear B Script

    Usage
    -----
    
    > alpha_to_linearb("to-so-jo pe-ma GRA 32")
    + 𐀵𐀰𐀍 𐀟𐀔 𐂎 𐄒𐄈

    """

    # output = input.split()
    # if numbers:
    #     for i in range(len(output)):
    #         if output[i].isnumeric():
    #             num_out = 0
    #             print(output[i])
    #             num = [int(j) for j in output[i]]
    #             tens = [10**n for n in range(len(num)-1,-1,-1)]
    #             for i in range(len(tens)):
    #                 num_out = num + numbers[str(num[i]*tens[i])]
    #         output[i] = num_out

    
    output = input.replace("-", "")

    # output = " ".join(output).replace("-", "")

    output = output.replace("*132", "𐂗")
    output = output.replace("*142", "𐂜")
    output = output.replace("*146", "𐂞")
    output = output.replace("*150", "𐂟")
    output = output.replace("*152", "𐂡")
    output = output.replace("*153", "𐂢")
    output = output.replace("*154", "𐂣")
    output = output.replace("*155", "𐃞")
    output = output.replace("*157", "𐂥")
    output = output.replace("*158", "𐂦")
    output = output.replace("*160", "𐂨")
    output = output.replace("*161", "𐂩")
    output = output.replace("*164", "𐂬")
    output = output.replace("*165", "𐂭")
    output = output.replace("*166", "𐂮")
    output = output.replace("*167", "𐂯")
    output = output.replace("*168", "𐂰")
    output = output.replace("*169", "𐂱")
    output = output.replace("*170", "𐂲")
    output = output.replace("*171", "𐂳")
    output = output.replace("*172", "𐂴")
    output = output.replace("*174", "𐂶")
    output = output.replace("*177", "𐂸")
    output = output.replace("*178", "𐂹")
    output = output.replace("*179", "𐂺")
    output = output.replace("*180", "𐂻")
    output = output.replace("*18", "𐁐")
    output = output.replace("*181", "𐂼")
    output = output.replace("*182", "𐂽")
    output = output.replace("*183", "𐂾")
    output = output.replace("*184", "𐂿")
    output = output.replace("*185", "𐃀")
    output = output.replace("*189", "𐃁")
    output = output.replace("*190", "𐃂")
    output = output.replace("*19", "𐁑")
    output = output.replace("*200", "𐃟")
    output = output.replace("*201", "𐃠")
    output = output.replace("*202", "𐃡")
    output = output.replace("*203", "𐃢")
    output = output.replace("*204", "𐃣")
    output = output.replace("*205", "𐃤")
    output = output.replace("*206", "𐃥")
    output = output.replace("*207", "𐃦")
    output = output.replace("*208", "𐃧")
    output = output.replace("*209", "𐃨")
    output = output.replace("*210", "𐃩")
    output = output.replace("*211", "𐃪")
    output = output.replace("*212", "𐃫")
    output = output.replace("*213", "𐃬")
    output = output.replace("*214", "𐃭")
    output = output.replace("*215", "𐃮")
    output = output.replace("*216", "𐃯")
    output = output.replace("*217", "𐃰")
    output = output.replace("*218", "𐃱")
    output = output.replace("*219", "𐃲")
    output = output.replace("*220", "𐃄")
    output = output.replace("*221", "𐃳")
    output = output.replace("*222", "𐃴")
    output = output.replace("*226", "𐃵")
    output = output.replace("*227", "𐃶")
    output = output.replace("*228", "𐃷")
    output = output.replace("*229", "𐃸")
    output = output.replace("*22", "𐁒")
    output = output.replace("*232", "𐃈")
    output = output.replace("*234", "𐃊")
    output = output.replace("*236", "𐃋")
    output = output.replace("*245", "𐃐")
    output = output.replace("*246", "𐃑")
    output = output.replace("*248", "𐃓")
    output = output.replace("*249", "𐃔")
    output = output.replace("*250", "𐃹")
    output = output.replace("*251", "𐃕")
    output = output.replace("*252", "𐃖")
    output = output.replace("*253", "𐃗")
    output = output.replace("*255", "𐃙")
    output = output.replace("*256", "𐃚")
    output = output.replace("*257", "𐃛")
    output = output.replace("*258", "𐃜")
    output = output.replace("*259", "𐃝")
    output = output.replace("*305", "𐃺")
    output = output.replace("*34", "𐁓")
    output = output.replace("*47", "𐁔")
    output = output.replace("*49", "𐁕")
    output = output.replace("*56", "𐁖")
    output = output.replace("*63", "𐁗")
    output = output.replace("*64", "𐁘")
    output = output.replace("*65", "𐀎")
    output = output.replace("*79", "𐁙")
    output = output.replace("*82", "𐁚")
    output = output.replace("*83", "𐁛")
    output = output.replace("*86", "𐁜")
    output = output.replace("*89", "𐁝")
    output = output.replace("AES", "𐂚")
    output = output.replace("ALVEUS", "𐃅")
    output = output.replace("ARBOR", "𐂷")
    output = output.replace("AREPA", "𐂘")
    output = output.replace("ARMA", "𐂫")
    output = output.replace("AROM", "𐂑")
    output = output.replace("AUR", "𐂛")
    output = output.replace("BIGAE", "𐃌")
    output = output.replace("BOSf", "𐂌")
    output = output.replace("BOSm", "𐂍")
    output = output.replace("CAPSUS", "𐃎")
    output = output.replace("CAPf", "𐂈")
    output = output.replace("CAPm", "𐂉")
    output = output.replace("CERV", "𐂂")
    output = output.replace("CORNU", "𐂠")
    output = output.replace("CURRUS", "𐃍")
    output = output.replace("CYP", "𐂒")
    output = output.replace("DIPTE", "𐃒")
    output = output.replace("EQUf", "𐂄")
    output = output.replace("EQUm", "𐂅")
    output = output.replace("EQU", "𐂃")
    output = output.replace("GALEA", "𐃃")
    output = output.replace("GRA", "𐂎")
    output = output.replace("HASTA", "𐃆")
    output = output.replace("HORD", "𐂏")
    output = output.replace("JACULUM", "𐃘")
    output = output.replace("KANAKO", "𐂔")
    output = output.replace("KAPO", "𐂓")
    output = output.replace("LANA", "𐂝")
    output = output.replace("LUNA", "𐂵")
    output = output.replace("MERI", "𐂙")
    output = output.replace("MUL", "𐂁")
    output = output.replace("OLE", "𐂕")
    output = output.replace("OLIV", "𐂐")
    output = output.replace("OVISf", "𐂆")
    output = output.replace("OVISm", "𐂇")
    output = output.replace("PUGIO", "𐃉")
    output = output.replace("ROTA", "𐃏")
    output = output.replace("SAGITTA", "𐃇")
    output = output.replace("SUSf", "𐂊")
    output = output.replace("SUSm", "𐂋")
    output = output.replace("TELA", "𐂧")
    output = output.replace("TUNICA", "𐂪")
    output = output.replace("TURO2", "𐂤")
    output = output.replace("VIN", "𐂖")
    output = output.replace("VIR", "𐂀")
    output = output.replace("da", "𐀅")
    output = output.replace("de", "𐀆")
    output = output.replace("di", "𐀇")
    output = output.replace("do", "𐀈")
    output = output.replace("du", "𐀉")
    output = output.replace("dwe", "𐁃")
    output = output.replace("dwo", "𐁄")
    output = output.replace("je", "𐀋")
    output = output.replace("jo", "𐀍")
    output = output.replace("ju2", "𐀎")
    output = output.replace("ju", "𐀎")
    output = output.replace("ka", "𐀏")
    output = output.replace("ke", "𐀐")
    output = output.replace("ki", "𐀑")
    output = output.replace("ko", "𐀒")
    output = output.replace("ku", "𐀓")
    output = output.replace("ma", "𐀔")
    output = output.replace("me", "𐀕")
    output = output.replace("mi", "𐀖")
    output = output.replace("mo", "𐀗")
    output = output.replace("mu", "𐀘")
    output = output.replace("na", "𐀙")
    output = output.replace("ne", "𐀚")
    output = output.replace("ni", "𐀛")
    output = output.replace("no", "𐀜")
    output = output.replace("nu", "𐀝")
    output = output.replace("nwa", "𐁅")
    output = output.replace("ja", "𐀊")
    output = output.replace("pa", "𐀞")
    output = output.replace("pe", "𐀟")
    output = output.replace("pi", "𐀠")
    output = output.replace("po", "𐀡")
    output = output.replace("pte", "𐁇")
    output = output.replace("pu2", "𐁆")
    output = output.replace("pu", "𐀢")
    output = output.replace("qa", "𐀣")
    output = output.replace("qe", "𐀤")
    output = output.replace("qi", "𐀥")
    output = output.replace("qo", "𐀦")
    output = output.replace("ra2", "𐁈")
    output = output.replace("ra3", "𐁉")
    output = output.replace("ra", "𐀨")
    output = output.replace("re", "𐀩")
    output = output.replace("ri", "𐀪")
    output = output.replace("ro2", "𐁊")
    output = output.replace("ro", "𐀫")
    output = output.replace("ru", "𐀬")
    output = output.replace("sa", "𐀭")
    output = output.replace("se", "𐀮")
    output = output.replace("si", "𐀯")
    output = output.replace("so", "𐀰")
    output = output.replace("su", "𐀱")
    output = output.replace("ta2", "𐁌")
    output = output.replace("ta", "𐀲")
    output = output.replace("te", "𐀳")
    output = output.replace("ti", "𐀴")
    output = output.replace("to", "𐀵")
    output = output.replace("tu", "𐀶")
    output = output.replace("two", "𐁍")
    output = output.replace("u", "𐀄")
    output = output.replace("wa", "𐀷")
    output = output.replace("we", "𐀸")
    output = output.replace("wi", "𐀹")
    output = output.replace("wo", "𐀺")
    output = output.replace("za", "𐀼")
    output = output.replace("ze", "𐀽")
    output = output.replace("zo", "𐀿")

    output = output.replace("e", "𐀁")
    output = output.replace("a2", "𐁀")
    output = output.replace("a3", "𐁁")
    output = output.replace("a", "𐀀")
    output = output.replace("i", "𐀂")
    output = output.replace("o", "𐀃")

    output = output.replace(",", "𐄀")
    output = output.replace("V", "𐄾")
    output = output.replace("M", "𐄸")
    output = output.replace("N", "𐄹")
    output = output.replace("T", "𐄼")
    output = output.replace("P", "𐄺")
    output = output.replace("Q", "𐄻")
    output = output.replace("L", "𐄷")
    output = output.replace("S", "𐄽")
    output = output.replace("Z", "𐄿")
    
    output = output.split()
    if numbers:
        for i in range(len(output)):
            if output[i].isnumeric():
                num_out = ""
                num = [int(j) for j in output[i]]
                tens = [10**n for n in range(len(num)-1,-1,-1)]
                for j in range(len(tens)):
                    num_out = num_out + aegean_numbers[str(num[j]*tens[j])]
                output[i] = num_out

    return " ".join(output)


if __name__ == "__main__":
    a = ["apiqoita doe-ra MUL 32",
         "ko-wa me-zo-e 5 ko-wa me-wi-jo-e 15",
         "ko-wo me-wi-jo-e 4"]
    b = [alpha_to_linearb(i) for i in a]
    for i in b:
        print(i)
        



#! /usr/bin/env python3

""" Oscan converter

The transliteration scheme is as follows

    ---------------------------------------------
    | a 𐌀 | b 𐌁 | g,k 𐌂 | d 𐌃 | e 𐌄 | v 𐌅 | z 𐌆 |
    | h 𐌇 | i 𐌉 | l   𐌋 | m 𐌌 | n 𐌍 | p 𐌐 | ś 𐌑 |
    | r 𐌓 | s 𐌔 | t   𐌕 | u 𐌖 | f 𐌚 | ú 𐌞 | í 𐌝 |
    ---------------------------------------------

"""

def alpha_to_oscan(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Oscan Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("a","𐌀")
    output = output.replace("b","𐌁")
    output = output.replace("g","𐌂")
    output = output.replace("k","𐌂")
    output = output.replace("d","𐌃")
    output = output.replace("e","𐌄")
    output = output.replace("v","𐌅")
    output = output.replace("z","𐌆")
    output = output.replace("h","𐌇")
    output = output.replace("i","𐌉")
    output = output.replace("l","𐌋")
    output = output.replace("m","𐌌")
    output = output.replace("n","𐌍")
    output = output.replace("p","𐌐")
    output = output.replace("ś","𐌑")
    output = output.replace("r","𐌓")
    output = output.replace("s","𐌔")
    output = output.replace("t","𐌕")
    output = output.replace("u","𐌖")
    output = output.replace("f","𐌚")
    output = output.replace("ú","𐌞")
    output = output.replace("í","𐌝")
    return output


if __name__ == "__main__":
       a = """
       puklu
       """
       b = alpha_to_oscan(a)
       print(b)



""" Vedic - Devanagari and IAST

The scheme follows the Harvard-Kyoto Standard.
Accents should be placed as following for DEVANAGARI
    - anudāttaḥ:
        > hk_to_deva(anudAttaH - a=)
        + अनुदात्तः - अ॒
    - svaritaḥ:
        > hk_to_deva(svaritaH - a+)
        + स्वरितः - अ॑

Otherwise, use ´, /, `. \\ and =, ^
"""


hk_dv_unicode = {'M': '\u0902', 'H': '\u0903',
                 'a': '\u0905', 'A': '\u0906', 'i': '\u0907', 'I': '\u0908',
                 'u': '\u0909', 'U': '\u090A', 'R': '\u090B', 'RR': '\u0960', 'lR': '\u090C',
                 'e': '\u090F', 'ai': '\u0910', 'o': '\u0913', 'au': '\u0914',
                 'k': '\u0915', 'kh': '\u0916', 'g': '\u0917', 'gh': '\u0918', 'G': '\u0919',
                 'c': '\u091A', 'ch': '\u091B', 'j': '\u091C', 'jh': '\u091D', 'J': '\u091E',
                 'T': '\u091F', 'Th': '\u0920', 'D': '\u0921', 'Dh': '\u0922', 'N': '\u0923',
                 't': '\u0924', 'th': '\u0925', 'd': '\u0926', 'dh': '\u0927', 'n': '\u0928',
                 'p': '\u092A', 'ph': '\u092B', 'b': '\u092C', 'bh': '\u092D', 'm': '\u092E',
                 'y': '\u092F', 'r': '\u0930', 'l': '\u0932', 'v': '\u0935',
                 'z': '\u0936', 'S': '\u0937', 's': '\u0938', 'h': '\u0939',
                 "'": '\u093D', 'oM': '\u0950', ' ': ' ', '|': '\u0964', '||': '\u0964',
                 "=": "॒", "+": "॑"}
hk_dv_vowel_diacritics = {'A': '\u093E', 'a': '',
                          'i': '\u093F', 'I': '\u0940',
                          'u': '\u0941', 'U': '\u0942',
                          'R': '\u0943', 'RR': '\u0944',
                          'lR': '\u0962',
                          'e': '\u0947', 'ai': '\u0948',
                          'o': '\u094b', 'au': '\u094C'}
hk_dv_vowels = ['A', 'a', 'i', 'I', 'u', 'U',
                'R', 'RR',
                'lR', 'e', 'ai', 'o', 'au']
hk_dv_consonants = ['k', 'g', 'G',
                    'c', 'j', 'J',
                    'T', 'D', 'N',
                    't', 'd', 'n',
                    'p', 'b', 'm',
                    'y', 'r', 'l', 'v',
                    'z', 'S', 's', 'h']
hk_dv_special_consonants = ['G', 'J', 'N', 'n', 'm',
                            'y', 'r', 'l', 'v',
                            'z', 'S', 's']
hk_dv_diacritics = ['M', 'H', '\'', '=', "+"]
hk_dv_punctuation = ['|', '||']


def hk_to_deva(input_text):

    """
    :param input_text: Text to be transliterated, written in Harvard-Kyoto.
    :return: Text in Devanagari.
    """

    if input_text[-1] != ' ':
        input_text = input_text.center(len(input_text) + 2)
    output_text = []
    i = -1

    for letter in input_text:
        i += 1
        if letter == " ":
            output_text.append(" ")
        elif letter not in hk_dv_unicode:
            output_text.append(letter)
        else:
            if letter in hk_dv_vowels:
                if letter == 'a':
                    if input_text[i + 1] == 'i':
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append(hk_dv_vowel_diacritics['ai'])
                        else:
                            output_text.append(hk_dv_unicode['ai'])
                    elif input_text[i + 1] == 'u':
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append(hk_dv_vowel_diacritics['au'])
                        else:
                            output_text.append(hk_dv_unicode['au'])
                    else:
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append('')
                        else:
                            output_text.append(hk_dv_unicode[letter])
                elif letter == 'i' or letter == 'u':
                    if input_text[i - 1] == 'a':
                        continue
                    else:
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append(hk_dv_vowel_diacritics[letter])
                        else:
                            output_text.append(hk_dv_unicode[letter])
                elif letter == 'R':
                    if input_text[i + 1] == 'R':
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append(hk_dv_vowel_diacritics['RR'])
                        else:
                            output_text.append(hk_dv_unicode['RR'])
                    elif input_text[i - 1] == 'R' or input_text[i - 1] == 'l':
                        continue
                    else:
                        if input_text[i - 1] in hk_dv_consonants:
                            output_text.append(hk_dv_vowel_diacritics[letter])
                        else:
                            output_text.append(hk_dv_unicode[letter])
                else:
                    if input_text[i - 1] in hk_dv_consonants:
                        output_text.append(hk_dv_vowel_diacritics[letter])
                    else:
                        output_text.append(hk_dv_unicode[letter])
            elif letter in hk_dv_consonants:
                if letter == 'l' and input_text[i + 1] == 'R':
                    if input_text[i - 1] in hk_dv_consonants:
                        output_text.append(hk_dv_vowel_diacritics['lR'])
                    else:
                        output_text.append(hk_dv_unicode['lR'])
                elif input_text[i + 1] == 'h' and letter not in hk_dv_special_consonants:
                    output_text.append(hk_dv_unicode['%sh' % letter])
                elif letter == 'h' and input_text[i - 1] in hk_dv_consonants:
                    if input_text[i+1] not in hk_dv_vowels:
                        output_text.append('\u094D')
                elif input_text[i + 1] not in hk_dv_vowels:
                    output_text.append(hk_dv_unicode[letter])
                    output_text.append('\u094D')
                else:
                    output_text.append(hk_dv_unicode[letter])
            else:
                output_text.append(hk_dv_unicode[letter])

    output_text = "".join(output_text)
    output_text = output_text.strip()
    return output_text


def hk_to_iast(input):
    output = input

    output = output.replace("a/", "á")
    output = output.replace("i/", "í")
    output = output.replace("u/", "ú")
    output = output.replace("e/", "é")
    output = output.replace("o/", "ó")
    output = output.replace("A/", "ā́")
    output = output.replace("I/", "ī́")
    output = output.replace("U/", "ū́")
    output = output.replace("A", "ā")
    output = output.replace("I", "ī")
    output = output.replace("U", "ū")
    output = output.replace("lRR/", "l̥̄́")
    output = output.replace("lRR ", "l̥̄")
    output = output.replace("lR/", "ĺ̥")
    output = output.replace("lR", "l̥")
    output = output.replace("RR/", "r̥̄́")
    output = output.replace("RR", "r̥̄")
    output = output.replace("R/", "ŕ̥")
    output = output.replace("R", "r̥")
    output = output.replace("T", "ṭ")
    output = output.replace("D", "ḍ")
    output = output.replace("N", "ṇ")
    output = output.replace("S", "ṣ")
    output = output.replace("z", "ś")
    output = output.replace("L", "ḷ")
    output = output.replace("H", "ḥ")
    output = output.replace("M", "ṃ")
    output = output.replace("G", "ṅ")
    output = output.replace("J", "ñ")
    output = output.replace("&", "m̐")

    return output

if __name__ == '__main__':
    print(hk_to_deva("svaritaH - a+"))



#! /usr/bin/env python3

""" Hieroglyphic Luwian script converter

Glyphs with known syllabic values should be written in lower-case, syllabically
and with the proper diacritic or numbered if +4. Glyphs with known logographic 
values should be written in upper-case. Variants of known glyphs should be
followed by one or more dots (.), generally the undotted variant is the more
frequent one.  Glyphs with unknown value should be written with an asterisk 
followed by the number (3 digits, including the 0).

Example:
    > pieoffice convert luwian "MAGNUS.REX MAGNUS-TONITRUS MAGNUS.REX HEROS ka-ra-ka-mi-sà REGIO REX || X-pa-VIR-ti-sa MAGNUS.REX HEROS INFANS-ní-mu-za || wa-tu-tá-a CORNU-ra-ti REGIO LIS arha.-SPHINX || *273"
    >>> 𔐒 𔖙𔓢 𔐒 𔐕 𔕢𔗷𔗧𔖻𔑶 𔔆 𔐑 || X𔕸𔕠𔑣𔗔 𔐒 𔐕 𔐰𔓵𔑾𔖪 || 𔗬𔑢𔐞𔗷 𔒂𔖱𔑣 𔔆 𔐘 𔓹𔒒 || 𔔴

Included graphic marks:
    "WD" for "𔖵"
    "WE" for "𔗷"
    "."  for "𔖲"
    "<"  for "𔗎"
    ">"  for "𔗏"

"""

def alpha_to_luwian(input):
    """ Converts text in Latin Alphabet to Hieroglyphic Luwian Script

    Each syllable should be separated by a sing dash, each word by a space.

    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Hieroglyphic Luwian Script

    Usage
    -----

    > alpha_to_luwian("EGO-mi u.-ra-hi-li-na")
    + .𔐀𔖻  𔑻𔖱𔗒𔔹𔐤.

    """
    output = input.replace("-","")


    output = output.replace("(DEUS)MONS.MENSA", "𔕍")
    output = output.replace("(DEUS)MONS.SARPA", "𔕍")
    output = output.replace("(DEUS)VIA+TERRA", "𔓧")

    # ASIGNS

    output = output.replace("*003", "𔐂")
    output = output.replace("*005", "𔐄")
    output = output.replace("*011", "𔐋")
    output = output.replace("*013", "𔐍")
    output = output.replace("*020", "𔐔")
    output = output.replace("*023", "𔐗")
    output = output.replace("*030", "𔐟")
    output = output.replace("*033", "𔐢")
    output = output.replace("*037", "𔐦")
    output = output.replace("*038", "𔐧")
    output = output.replace("*040", "𔐪")
    output = output.replace("*044", "𔐯")
    output = output.replace("*047", "𔐵")
    output = output.replace("*048", "𔐶")
    output = output.replace("*050", "𔐸")
    output = output.replace("*051", "𔐹")
    output = output.replace("*054", "𔐼")
    output = output.replace("*060", "𔑂")
    output = output.replace("*061", "𔑃")
    output = output.replace("*063", "𔑅")
    output = output.replace("*064", "𔑆")
    output = output.replace("*067", "𔑌")
    output = output.replace("*068", "𔑍")
    output = output.replace("*069", "𔑎")
    output = output.replace("*071", "𔑐")
    output = output.replace("*072", "𔑑")
    output = output.replace("*074", "𔑓")
    output = output.replace("*075", "𔑔")
    output = output.replace("*076", "𔑕")
    output = output.replace("*077", "𔑖")
    output = output.replace("*087", "𔑠")
    output = output.replace("*088", "𔑡")
    output = output.replace("*092", "𔑥")
    output = output.replace("*094", "𔑧")
    output = output.replace("*106", "𔑽")
    output = output.replace("*113", "𔒉")
    output = output.replace("*116", "𔒍")
    output = output.replace("*117", "𔒎")
    output = output.replace("*118", "𔒏")
    output = output.replace("*119", "𔒐")
    output = output.replace("*122", "𔒓")
    output = output.replace("*123", "𔒔")
    output = output.replace("*124", "𔒕")
    output = output.replace("*126", "𔒘")
    output = output.replace("*127", "𔒙")
    output = output.replace("*129", "𔒛")
    output = output.replace("*135A", "𔒢")
    output = output.replace("*136", "𔒣")
    output = output.replace("*139", "𔒦")
    output = output.replace("*140", "𔒧")
    output = output.replace("*141", "𔒨")
    output = output.replace("*142", "𔒩")
    output = output.replace("*143", "𔒪")
    output = output.replace("*144", "𔒫")
    output = output.replace("*145", "𔒬")
    output = output.replace("*146", "𔒭")
    output = output.replace("*147", "𔒮")
    output = output.replace("*149", "𔒰")
    output = output.replace("*150", "𔒱")
    output = output.replace("*152", "𔒳")
    output = output.replace("*154", "𔒵")
    output = output.replace("*155", "𔒶")
    output = output.replace("*156", "𔒷")
    output = output.replace("*157", "𔒸")
    output = output.replace("*158", "𔒹")
    output = output.replace("*159", "𔒺")
    output = output.replace("*161", "𔒼")
    output = output.replace("*162", "𔒽")
    output = output.replace("*163", "𔒾")
    output = output.replace("*164", "𔒿")
    output = output.replace("*167", "𔓂")
    output = output.replace("*168", "𔓃")
    output = output.replace("*169", "𔓄")
    output = output.replace("*170", "𔓅")
    output = output.replace("*171", "𔓆")
    output = output.replace("*180", "𔓏")
    output = output.replace("*183", "𔓒")
    output = output.replace("*184", "𔓓")
    output = output.replace("*185", "𔓔")
    output = output.replace("*186", "𔓕")
    output = output.replace("*187", "𔓖")
    output = output.replace("*188", "𔓗")
    output = output.replace("*189", "𔓘")
    output = output.replace("*194", "𔓝")
    output = output.replace("*195", "𔓞")
    output = output.replace("*198", "𔓡")
    output = output.replace("*203", "𔓨")
    output = output.replace("*205", "𔓪")
    output = output.replace("*206", "𔓫")
    output = output.replace("*208", "𔓮")
    output = output.replace("*211", "𔓲")
    output = output.replace("*213", "𔓴")
    output = output.replace("*217", "𔓺")
    output = output.replace("*218", "𔓻")
    output = output.replace("*219", "𔓼")
    output = output.replace("*220", "𔓽")
    output = output.replace("*222", "𔓿")
    output = output.replace("*224", "𔔁")
    output = output.replace("*227", "𔔄")
    output = output.replace("*230", "𔔈")
    output = output.replace("*232", "𔔊")
    output = output.replace("*233", "𔔋")
    output = output.replace("*234", "𔔌")
    output = output.replace("*235", "𔔍")
    output = output.replace("*236", "𔔎")
    output = output.replace("*238", "𔔐")
    output = output.replace("*240", "𔔒")
    output = output.replace("*242", "𔔔")
    output = output.replace("*253", "𔔟")
    output = output.replace("*256", "𔔢")
    output = output.replace("*258", "𔔤")
    output = output.replace("*259", "𔔥")
    output = output.replace("*260", "𔔦")
    output = output.replace("*261", "𔔧")
    output = output.replace("*262", "𔔨")
    output = output.replace("*263", "𔔩")
    output = output.replace("*265", "𔔫")
    output = output.replace("*270", "𔔱")
    output = output.replace("*271", "𔔲")
    output = output.replace("*273", "𔔴")
    output = output.replace("*274", "𔔵")
    output = output.replace("*275", "𔔶")
    output = output.replace("*279", "𔔺")
    output = output.replace("*282", "𔔽")
    output = output.replace("*284", "𔔿")
    output = output.replace("*285", "𔕀")
    output = output.replace("*287", "𔕂")
    output = output.replace("*293", "𔕉")
    output = output.replace("*295", "𔕌")
    output = output.replace("*297", "𔕎")
    output = output.replace("*302", "𔕔")
    output = output.replace("*308", "𔕚")
    output = output.replace("*310", "𔕝")
    output = output.replace("*311", "𔕞")
    output = output.replace("*312", "𔕟")
    output = output.replace("*317", "𔕤")
    output = output.replace("*320", "𔕧")
    output = output.replace("*321", "𔕨")
    output = output.replace("*323", "𔕪")
    output = output.replace("*324", "𔕫")
    output = output.replace("*329A", "𔕱")
    output = output.replace("*333", "𔕷")
    output = output.replace("*339", "𔖀")
    output = output.replace("*342", "𔖃")
    output = output.replace("*348", "𔖉")
    output = output.replace("*349", "𔖊")
    output = output.replace("*350", "𔖋")
    output = output.replace("*351", "𔖌")
    output = output.replace("*352", "𔖍")
    output = output.replace("*353", "𔖎")
    output = output.replace("*354", "𔖏")
    output = output.replace("*356", "𔖑")
    output = output.replace("*357", "𔖒")
    output = output.replace("*359A", "𔖕")
    output = output.replace("*359", "𔖔")
    output = output.replace("*361", "𔖗")
    output = output.replace("*365", "𔖜")
    output = output.replace("*373", "𔖦")
    output = output.replace("*374", "𔖧")
    output = output.replace("*375", "𔖨")
    output = output.replace("*394", "𔖾")
    output = output.replace("*396", "𔗀")
    output = output.replace("*398", "𔗂")
    output = output.replace("*401", "𔗅")
    output = output.replace("*403", "𔗇")
    output = output.replace("*405", "𔗉")
    output = output.replace("*406", "𔗊")
    output = output.replace("*407", "𔗋")
    output = output.replace("*408", "𔗌")
    output = output.replace("*409", "𔗍")
    output = output.replace("*414", "𔗓")
    output = output.replace("*416", "𔗕")
    output = output.replace("*418", "𔗗")
    output = output.replace("*420", "𔗙")
    output = output.replace("*424", "𔗝")
    output = output.replace("*425", "𔗞")
    output = output.replace("*426", "𔗟")
    output = output.replace("*427", "𔗠")
    output = output.replace("*428", "𔗡")
    output = output.replace("*431", "𔗤")
    output = output.replace("*432", "𔗥")
    output = output.replace("*436", "𔗩")
    output = output.replace("*437", "𔗪")
    output = output.replace("*440", "𔗭")
    output = output.replace("*441", "𔗮")
    output = output.replace("*442", "𔗯")
    output = output.replace("*443", "𔗰")
    output = output.replace("*444", "𔗱")
    output = output.replace("*448", "𔗵")
    output = output.replace("*449", "𔗶")
    output = output.replace("*452", "𔗺")
    output = output.replace("*453", "𔗻")
    output = output.replace("*454", "𔗼")
    output = output.replace("*457A", "𔘀")
    output = output.replace("*457", "𔗿")
    output = output.replace("*458", "𔘁")
    output = output.replace("*459", "𔘂")
    output = output.replace("*460", "𔘃")
    output = output.replace("*462", "𔘅")
    output = output.replace("*463", "𔘆")
    output = output.replace("*464", "𔘇")
    output = output.replace("*465", "𔘈")
    output = output.replace("*466", "𔘉")
    output = output.replace("*467", "𔘊")
    output = output.replace("*468", "𔘋")
    output = output.replace("*469", "𔘌")
    output = output.replace("*471", "𔘎")
    output = output.replace("*472", "𔘏")
    output = output.replace("*473", "𔘐")
    output = output.replace("*475", "𔘒")
    output = output.replace("*476", "𔘓")
    output = output.replace("*477", "𔘔")
    output = output.replace("*478", "𔘕")
    output = output.replace("*479", "𔘖")
    output = output.replace("*480", "𔘗")
    output = output.replace("*481", "𔘘")
    output = output.replace("*482", "𔘙")
    output = output.replace("*483", "𔘚")
    output = output.replace("*484", "𔘛")
    output = output.replace("*485", "𔘜")
    output = output.replace("*486", "𔘝")
    output = output.replace("*487", "𔘞")
    output = output.replace("*489", "𔘠")
    output = output.replace("*490", "𔘡")
    output = output.replace("*491", "𔘢")
    output = output.replace("*492", "𔘣")
    output = output.replace("*493", "𔘤")
    output = output.replace("*494", "𔘥")
    output = output.replace("*495", "𔘦")
    output = output.replace("*496", "𔘧")
    output = output.replace("*497", "𔘨")
    output = output.replace("*501", "𔘩")
    output = output.replace("*502", "𔘪")
    output = output.replace("*503", "𔘫")
    output = output.replace("*504", "𔘬")
    output = output.replace("*505", "𔘭")
    output = output.replace("*507", "𔘯")
    output = output.replace("*509", "𔘱")
    output = output.replace("*510", "𔘲")
    output = output.replace("*511", "𔘳")
    output = output.replace("*512", "𔘴")
    output = output.replace("*513", "𔘵")
    output = output.replace("*514", "𔘶")
    output = output.replace("*515", "𔘷")
    output = output.replace("*516", "𔘸")
    output = output.replace("*517", "𔘹")
    output = output.replace("*518", "𔘺")
    output = output.replace("*519", "𔘻")
    output = output.replace("*520", "𔘼")
    output = output.replace("*521", "𔘽")
    output = output.replace("*522", "𔘾")
    output = output.replace("*523", "𔘿")
    output = output.replace("*526", "𔙂")
    output = output.replace("*530", "𔙆")

    output = output.replace("ADORARE", "𔐅")
    output = output.replace("AEDIFICARE", "𔔘")
    output = output.replace("AEDIFICIUM+MINUS", "𔔗")
    output = output.replace("AEDIFICIUM.PONERE", "𔔘")
    output = output.replace("AEDIFICIUM", "𔔖")
    output = output.replace("ALA", "𔑗")
    output = output.replace("AMPLECTI", "𔐈")
    output = output.replace("ANIMAL", "𔗈")
    output = output.replace("ANNUS+ANNUS", "𔖁")
    output = output.replace("ANNUS", "𔕺")
    output = output.replace("APER", "𔙃")
    output = output.replace("AQUILA", "𔒟")
    output = output.replace("ARGENTUM", "𔔣")
    output = output.replace("ASCIA", "𔔼")
    output = output.replace("ASINUS", "𔑯")
    output = output.replace("ASINUS2", "𔑱")
    output = output.replace("ASINUS2A", "𔑲")
    output = output.replace("AUDIRE+tu+mi", "𔑒")
    output = output.replace("AURIGA", "𔕄")
    output = output.replace("AURIGA2", "𔕅")
    output = output.replace("AURIS+tu+mi", "𔑒")
    output = output.replace("AVIS2", "𔒞")
    output = output.replace("AVIS3", "𔒜")
    output = output.replace("AVIS4", "𔒟")
    output = output.replace("AVIS5", "𔒝")
    output = output.replace("AVIS-x", "𔒡")
    output = output.replace("AVIS", "𔒚")
    output = output.replace("AVUS", "𔕳")
    output = output.replace("BESTIA", "𔑪")
    output = output.replace("BIBERE", "𔐇")
    output = output.replace("BONUS2", "𔖢")
    output = output.replace("BONUS", "𔓀")
    output = output.replace("BOS+MI", "𔑾")
    output = output.replace("BOS.MI", "𔒀")
    output = output.replace("BOS.", "𔑻")
    output = output.replace("BOS", "𔑺")
    output = output.replace("BOS2.MI", "𔒁")
    output = output.replace("BOS2", "𔑼")
    output = output.replace("BRACCHIUM", "𔐡")
    output = output.replace("CAELUM", "𔓑")
    output = output.replace("CANIS2", "𔑭")
    output = output.replace("CANIS", "𔑬")
    output = output.replace("CAPERE+SCALPRUM", "𔕲")
    output = output.replace("CAPERE2.CAPERE2", "𔐭")
    output = output.replace("CAPERE2", "𔐮")
    output = output.replace("CAPERE", "𔐫")
    output = output.replace("CAPRA2A", "𔑹")
    output = output.replace("CAPRA2", "𔑸")
    output = output.replace("CAPRA", "𔑶")
    output = output.replace("CAPUT+SCALPRUM", "𔐊")
    output = output.replace("CAPUT", "𔐉")
    output = output.replace("CASTRUM", "𔔉")
    output = output.replace("CENTUM", "𔗃")
    output = output.replace("CERVUS3", "𔑵")
    output = output.replace("CERVUS2", "𔑴")
    output = output.replace("CERVUS", "𔑳")
    output = output.replace("CONTRACTUS", "𔖅")
    output = output.replace("CORNU+CAPUT", "𔙀")
    output = output.replace("CORNU", "𔒂")
    output = output.replace("CRUS+FLUMEN", "𔑜")
    output = output.replace("CRUS.CRUS", "𔑟")
    output = output.replace("CRUS2", "𔑝")
    output = output.replace("CRUS", "𔑛")
    output = output.replace("CRUX2", "𔕜")
    output = output.replace("CRUX", "𔕛")
    output = output.replace("CUBITUM", "𔔕")
    output = output.replace("CUM", "𔑀")
    output = output.replace("CURRERE", "𔘰")
    output = output.replace("CURRUS", "𔕃")
    output = output.replace("DARE.DARE", "𔑊")
    output = output.replace("DARE", "𔑈")
    output = output.replace("DECEM", "𔗁")
    output = output.replace("DELERE", "𔔚")
    output = output.replace("DEUS.DOMUS", "𔔛")
    output = output.replace("DEUS", "𔖖")
    output = output.replace("DIES", "𔖓")

    # MAGNUS
    output = output.replace("MAGNUS.DOMINA", "𔐐")
    output = output.replace("MAGNUS.DOMUS", "𔔜")
    output = output.replace("MAGNUS.FILIA", "𔐴")
    output = output.replace("MAGNUS.REX", "𔐒")

    # REX

    output = output.replace("REX.FILIA", "𔐳")
    output = output.replace("REX.FILIUS", "𔐲")
    output = output.replace("REX.INFANS.FILIUS", "𔐲")

    output = output.replace("MAGNUS", "𔖙")
    output = output.replace("DOMINA", "𔐏")
    output = output.replace("DOMINUS", "𔖺")
    output = output.replace("FEMINA", "𔑘")
    output = output.replace("FILIA", "𔐱")
    output = output.replace("FILIUS", "𔐰")
    output = output.replace("DOMUS+MINUS", "𔔚")
    output = output.replace("DOMUS+SCALA", "𔔞")
    output = output.replace("DOMUS+x", "𔔝")
    output = output.replace("DOMUS", "𔔙")
    output = output.replace("EDERE", "𔐆")
    output = output.replace("EGO2", "𔐁")
    output = output.replace("EGO", "𔐀")
    output = output.replace("ENSIS", "𔐻")
    output = output.replace("EQUUS", "𔑮")
    output = output.replace("EUNUCHUS2", "𔔠")
    output = output.replace("EUNUCHUS", "𔘑")
    output = output.replace("EXERCITUS", "𔔰")
    output = output.replace("FINES+ha", "𔓹")
    output = output.replace("FINES", "𔓸")
    output = output.replace("FLUMEN", "𔓳")
    output = output.replace("FONS", "𔓶")
    output = output.replace("FORTIS", "𔐝")
    output = output.replace("FRATER2", "𔔷")
    output = output.replace("FRATER", "𔐰")
    output = output.replace("FRONS", "𔐚")
    output = output.replace("FULGUR", "𔓣")
    output = output.replace("FUSUS", "𔕗")
    output = output.replace("GENUFLECTERE", "𔑞")
    output = output.replace("GRYLLUS", "𔒑")
    output = output.replace("HASTARIUS", "𔓈")
    output = output.replace("HATTI+LI", "𔓠")
    output = output.replace("HATTUSILI", "𔓠")
    output = output.replace("HATTI", "𔓟")
    output = output.replace("HEROS", "𔐕")
    output = output.replace("HORDEUM", "𔓎")
    output = output.replace("HORREUM", "𔔡")
    output = output.replace("IACULUM", "𔕀")
    output = output.replace("INFANS", "𔐰")
    output = output.replace("INFRA", "𔐿")
    output = output.replace("ISHUWA", "𔔃")
    output = output.replace("IUDEX+la", "𔔸")
    output = output.replace("IUDEX+ra", "𔖤")
    output = output.replace("IUDEX+ri", "𔖤")
    output = output.replace("IUDEX+tara", "𔖤")
    output = output.replace("IUDEX+tari", "𔖤")
    output = output.replace("IUDEX.la", "𔔸")
    output = output.replace("IUDEX", "𔖣")
    output = output.replace("IUSTITIA", "𔖣")
    output = output.replace("JANUS", "𔒯")
    output = output.replace("LAPIS+SCALPRUM", "𔔭")
    output = output.replace("LAPIS", "𔔮")
    output = output.replace("LECTUS", "𔕓")
    output = output.replace("LEO+MONS.tu+LEO", "𔓭")
    output = output.replace("LEO", "𔑪")
    output = output.replace("LEO2", "𔑫")
    output = output.replace("LEPUS2", "𔒌")
    output = output.replace("LEPUS", "𔒋")
    output = output.replace("LIBARE", "𔐜")
    output = output.replace("LIBATIO", "𔒤")
    output = output.replace("LIGARE", "𔐠")
    output = output.replace("LINGERE", "𔒈")
    output = output.replace("LINGUA+CLAVUS", "𔓌")
    output = output.replace("LINGUA-x", "𔙅")
    output = output.replace("LINGUA", "𔓊")
    output = output.replace("LIS", "𔐘")
    output = output.replace("LITUS+na", "𔐥")
    output = output.replace("LITUUS+U", "𔒊")
    output = output.replace("LITUUS", "𔖫")
    output = output.replace("LOCUS", "𔓤")
    output = output.replace("LONGUS", "𔑄")
    output = output.replace("LOQUI", "𔐖")
    output = output.replace("LUNA", "𔓜")
    output = output.replace("MALLEUS", "𔔻")
    output = output.replace("MALUS2", "𔖠")
    output = output.replace("MALUS", "𔖟")
    output = output.replace("MANDARE2", "𔑋")
    output = output.replace("MANDARE", "𔑊")
    output = output.replace("MANUS+CULTER", "𔐻")
    output = output.replace("MANUS+MINUS", "𔑄")
    output = output.replace("MANUS.CULTER", "𔐺")
    output = output.replace("CULTER", "𔕿")
    output = output.replace("MANUS", "𔑁")
    output = output.replace("MATER", "𔑘")
    output = output.replace("MENSA2", "𔕋")
    output = output.replace("MILLE", "𔗄")
    output = output.replace("MINUS", "𔖮")
    output = output.replace("MORI", "𔖯")
    output = output.replace("MONS2", "𔐃")
    output = output.replace("MONS", "𔓬")
    output = output.replace("MURSILI", "𔔅")
    output = output.replace("NEG2", "𔕵")
    output = output.replace("NEG3", "𔕶")
    output = output.replace("NEG", "𔕴")
    output = output.replace("NEPOS", "𔕒")
    output = output.replace("OCCIDENS", "𔖬")
    output = output.replace("OCULUS", "𔐙")
    output = output.replace("OMNIS2", "𔗣")
    output = output.replace("OMNIS(+mi)", "𔖝")
    output = output.replace("OMNIS", "𔖝")
    output = output.replace("ORIENS", "𔓛")
    output = output.replace("OVIS2", "𔒆")
    output = output.replace("OVIS3", "𔒇")
    output = output.replace("OVIS", "𔒄")
    output = output.replace("PANIS.SCUTELLA", "𔗛")
    output = output.replace("PANIS", "𔓐")
    output = output.replace("PASTOR", "𔗫")
    output = output.replace("PES.REGIO", "𔔬")
    output = output.replace("mí.REGIO", "𔔇")
    output = output.replace("PES.SCALA.ROTAE", "𔑤")
    output = output.replace("PES2.PES2", "𔑨")
    output = output.replace("PES2.PES", "𔑩")
    output = output.replace("PES2", "𔑦")
    output = output.replace("PES", "𔑣")
    output = output.replace("PISCIS", "𔒥")
    output = output.replace("PITHOS.SCUTELLA", "𔕺")
    output = output.replace("PITHOS..", "𔖄")
    output = output.replace("PITHOS.", "𔕾")
    output = output.replace("PITHOS", "𔕺")
    output = output.replace("POCULUM", "𔖇")
    output = output.replace("PODIUM", "𔔪")
    output = output.replace("PONERE", "𔑇")
    output = output.replace("PORTA2", "𔔑")
    output = output.replace("PORTA", "𔔏")
    output = output.replace("POST", "𔐣")
    output = output.replace("PRAE", "𔐎")
    output = output.replace("PRINCEPS", "𔙁")
    output = output.replace("PROPHETA", "𔙀")
    output = output.replace("PUGNUS+PUGNUS", "𔐠")
    output = output.replace("PUGNUS+x", "𔐩")
    output = output.replace("PUGNUS", "𔐨")
    output = output.replace("PURUS", "𔕩")
    output = output.replace("REGIO", "𔔆")
    output = output.replace("REL", "𔕰")
    output = output.replace("REX", "𔐑")
    output = output.replace("ROTA", "𔕈")
    output = output.replace("SACERDOS2", "𔖥")
    output = output.replace("SACERDOS", "𔖐")
    output = output.replace("SARA", "𔕕")
    output = output.replace("SARI", "𔕕")
    output = output.replace("SARMA2", "𔑚")
    output = output.replace("SARMA", "𔑙")
    output = output.replace("SARPA", "𔕋")
    output = output.replace("SCRIBA", "𔕭")
    output = output.replace("SCUTELLA", "𔗆")
    output = output.replace("SCUTUM", "𔔳")
    output = output.replace("SERVUS", "𔖷")
    output = output.replace("SIGILLUM", "𔕮")
    output = output.replace("SOL", "𔓚")
    output = output.replace("SOL2.THRONUS/MENSA", "𔕌")
    output = output.replace("MENSA", "𔕊")
    output = output.replace("SOL2", "𔓙")
    output = output.replace("SOLIUM", "𔕐")
    output = output.replace("SPHINX", "𔒒")
    output = output.replace("STATUA", "𔐌")
    output = output.replace("STELE", "𔔭")
    output = output.replace("SUB", "𔐿")
    output = output.replace("SUPER", "𔑏")
    output = output.replace("TELIPINU", "𔒲")
    output = output.replace("TERRA", "𔓤")
    output = output.replace("TESHUB", "𔕥")
    output = output.replace("THRONUS..", "𔕍")
    output = output.replace("THRONUS.", "𔕋")
    output = output.replace("THRONUS2", "𔕏")
    output = output.replace("THRONUS", "𔕊")
    output = output.replace("TONITRUS", "𔓢")
    output = output.replace("UNGULA", "𔒗")
    output = output.replace("UNUS", "𔖭")
    output = output.replace("URBS+li", "𔔅")
    output = output.replace("URBS-li", "𔔅")
    output = output.replace("URBS", "𔔂")
    output = output.replace("URCEUS", "𔖆")
    output = output.replace("VACUUS", "𔔗")
    output = output.replace("VAS", "𔖂")
    output = output.replace("VERSUS", "𔐛")
    output = output.replace("VIR2.MINUS", "𔖯")
    output = output.replace("VIR2A", "𔖶")
    output = output.replace("VIR2", "𔖵")
    output = output.replace("VIR", "𔕠")
    output = output.replace("VIA+TERRA+SCALPRUM", "𔓦")
    output = output.replace("VIA+TERRA.SCALPRUM", "𔓥")
    output = output.replace("VIA", "𔓾")
    output = output.replace("SCALPRUM", "𔔯")
    output = output.replace("VITA", "𔖡")
    output = output.replace("VITELLUS", "𔒃")
    output = output.replace("VITIS", "𔒻")
    output = output.replace("WD", "𔖵")
    output = output.replace("WE", "𔗷")
    output = output.replace("zuwa", "𔕀")
    output = output.replace("ha-x", "𔕡")
    output = output.replace("hala", "𔕈")
    output = output.replace("hali", "𔕈")
    output = output.replace("hana", "𔘮")
    output = output.replace("hara", "𔕆")
    output = output.replace("hari", "𔕆")
    output = output.replace("huru", "𔗹")
    output = output.replace("hu", "𔕙")
    output = output.replace("hwi-x", "𔓎")
    output = output.replace("hwa.", "𔘰")
    output = output.replace("hwi.", "𔘰")
    output = output.replace("há-li", "𔓠")
    output = output.replace("há", "𔓟")
    output = output.replace("hí", "𔕘")
    output = output.replace("hú", "𔖈")
    output = output.replace("kar", "𔕢")
    output = output.replace("ka", "𔗧")
    output = output.replace("ki-x", "𔔓")
    output = output.replace("ki", "𔗳")
    output = output.replace("ku", "𔗜")
    output = output.replace("kwa", "𔕰")
    output = output.replace("kwi", "𔕰")
    output = output.replace("ká.", "𔐿")
    output = output.replace("ká", "𔐾")
    output = output.replace("la..", "𔗲")
    output = output.replace("la.", "𔕦")
    output = output.replace("la+la", "𔓋")
    output = output.replace("la+ra+a", "𔓍")
    output = output.replace("la-x", "𔗽")
    output = output.replace("li..", "𔗲")
    output = output.replace("li.", "𔕦")
    output = output.replace("li-x", "𔒗")
    output = output.replace("lignum", "𔖰")
    output = output.replace("lu", "𔗲")
    output = output.replace("lá", "𔓇")
    output = output.replace("lì", "𔕇")
    output = output.replace("lí.", "𔒖")
    output = output.replace("lí", "𔓇")
    output = output.replace("ma..", "𔒆")
    output = output.replace("ma.", "𔒅")
    output = output.replace("ma", "𔒄")
    output = output.replace("ma-x.", "𔘄")
    output = output.replace("ma-x", "𔒃")
    output = output.replace("mi", "𔖻")
    output = output.replace("muwa...", "𔒁")
    output = output.replace("muwa..", "𔒀")
    output = output.replace("muwa.", "𔑿")
    output = output.replace("muwa", "𔑾")
    output = output.replace("mu....", "𔖛")
    output = output.replace("mu...", "𔒁")
    output = output.replace("mu..", "𔒀")
    output = output.replace("mu.", "𔑿")
    output = output.replace("mu", "𔑾")
    output = output.replace("mà", "𔕖")
    output = output.replace("má", "𔖘")
    output = output.replace("mì", "𔖷")
    output = output.replace("mí", "𔗘")
    output = output.replace("ni-x", "𔗴")
    output = output.replace("nu", "𔒴")
    output = output.replace("nà", "𔑝")
    output = output.replace("ná", "𔕵")
    output = output.replace("nì", "𔐽")
    output = output.replace("ní", "𔓵")
    output = output.replace("nú", "𔖿")
    output = output.replace("pa-x", "𔓐")
    output = output.replace("pari", "𔐎")
    output = output.replace("pi", "𔑈")
    output = output.replace("pi.", "𔑉")
    output = output.replace("pu", "𔕯")
    output = output.replace("pú", "𔗣")
    output = output.replace("ru", "𔗑")
    output = output.replace("rú..", "𔑵")
    output = output.replace("rú.", "𔑴")
    output = output.replace("rú", "𔑳")
    output = output.replace("sa-x", "𔗖")
    output = output.replace("sa4", "𔗆")
    output = output.replace("sa5", "𔕮")
    output = output.replace("sa6", "𔔀")
    output = output.replace("sa7", "𔕣")
    output = output.replace("sa8", "𔖭")
    output = output.replace("sara", "𔑏")
    output = output.replace("sari", "𔑏")
    output = output.replace("sa", "𔗔")
    output = output.replace("si", "𔓉")
    output = output.replace("su", "𔖢")
    output = output.replace("sà...", "𔑹")
    output = output.replace("sà..", "𔑸")
    output = output.replace("sà.", "𔑷")
    output = output.replace("sà", "𔑶")
    output = output.replace("sá", "𔗦")
    output = output.replace("sí-x", "𔗾")
    output = output.replace("sú", "𔒂")
    output = output.replace("ta-x", "𔐭")
    output = output.replace("ta.", "𔑰")
    output = output.replace("ta4", "𔕦")
    output = output.replace("ta5", "𔓇")
    output = output.replace("ta6", "𔑛")
    output = output.replace("tala", "𔖞")
    output = output.replace("tana", "𔗢")
    output = output.replace("tapa.", "𔒌")
    output = output.replace("tapa", "𔒋")
    output = output.replace("tara.", "𔖸")
    output = output.replace("tara", "𔖹")
    output = output.replace("tari.", "𔖸")
    output = output.replace("tari", "𔖹")
    output = output.replace("ta", "𔑯")
    output = output.replace("ti4", "𔕦")
    output = output.replace("ti5", "𔓇")
    output = output.replace("ti", "𔑣")
    output = output.replace("tu4", "𔔆")
    output = output.replace("tuzzi", "𔔾")
    output = output.replace("tu", "𔑢")
    output = output.replace("tà.", "𔐬")
    output = output.replace("tà", "𔐫")
    output = output.replace("tá", "𔐞")
    output = output.replace("tì", "𔙄")
    output = output.replace("tí", "𔘟")
    output = output.replace("tù", "𔕭")
    output = output.replace("tú", "𔕬")
    output = output.replace("u...", "𔖚")
    output = output.replace("u..", "𔑼")
    output = output.replace("u.", "𔑻")
    output = output.replace("urhi", "𔗘")
    output = output.replace("ur", "𔖙")
    output = output.replace("us", "𔗚")
    output = output.replace("u", "𔑺")
    output = output.replace("wa5", "𔓩")
    output = output.replace("wa5.", "𔓬")
    output = output.replace("wa6", "𔓤")
    output = output.replace("wa7", "𔕁")
    output = output.replace("wa9", "𔔻")
    output = output.replace("wi(ya)", "𔒻")
    output = output.replace("wi.", "𔒻")
    output = output.replace("wi5", "𔓩")
    output = output.replace("wi5.", "𔓬")
    output = output.replace("wi6", "𔓤")
    output = output.replace("wi7", "𔕁")
    output = output.replace("wi9", "𔔻")
    output = output.replace("wi", "𔗬")
    output = output.replace("wà", "𔓀")
    output = output.replace("wá", "𔓁")
    output = output.replace("wì", "𔓀")
    output = output.replace("wí", "𔓁")
    output = output.replace("za-x", "𔕽")
    output = output.replace("za.", "𔖩")
    output = output.replace("za4", "𔒈")
    output = output.replace("za", "𔖪")
    output = output.replace("zi4", "𔒚")
    output = output.replace("zi", "𔖩")
    output = output.replace("zà", "𔕼")
    output = output.replace("zá", "𔕹")
    output = output.replace("zì.", "𔕻")
    output = output.replace("zì", "𔕺")
    output = output.replace("zí", "𔕠")
    output = output.replace("wa", "𔗬")
    output = output.replace("hi", "𔗒")
    output = output.replace("li", "𔔹")
    output = output.replace("pa", "𔕸")
    output = output.replace("la", "𔓊")

    #  Vowels
    output = output.replace("arha.", "𔓹")
    output = output.replace("arha", "𔓸")
    output = output.replace("ha", "𔓷")
    output = output.replace("a+ra", "𔗸")
    output = output.replace("a+ri", "𔗸")
    output = output.replace("a+tá", "𔐷")
    output = output.replace("a-x", "𔗨")
    output = output.replace("ara", "𔒟")
    output = output.replace("ara.", "𔒠")
    output = output.replace("ari", "𔒟")
    output = output.replace("ari.", "𔒠")
    output = output.replace("i(a)", "𔓯")
    output = output.replace("i+ra", "𔓰")
    output = output.replace("i+ri", "𔓰")
    output = output.replace("ia", "𔓱")
    output = output.replace("ra", "𔖱")
    output = output.replace("ri", "𔖱")
    output = output.replace("na", "𔐤")
    output = output.replace("ni", "𔗐")
    output = output.replace("ià", "𔖬")
    output = output.replace("iá", "𔕑")
    output = output.replace("a", "𔗷")
    output = output.replace("i", "𔓯")
    output = output.replace("á", "𔐓")
    output = output.replace("í", "𔕐")


    # Numbers

    output = output.replace("12", "𔘍")
    output = output.replace("1", "𔖭")
    output = output.replace("1", "𔗁")
    output = output.replace("1", "𔗃")
    output = output.replace("1", "𔗄")
    output = output.replace("2.", "𔖴")
    output = output.replace("2", "𔖳")
    output = output.replace("3", "𔖸")
    output = output.replace("4", "𔖻")
    output = output.replace("5", "𔖼")
    output = output.replace("8", "𔖽")
    output = output.replace("9", "𔖿")

    output = output.replace(".", "𔖲")

    output = output.replace("<", "𔗎")
    output = output.replace(">", "𔗏")

    return output


if __name__ == "__main__":
    # a = ["MAGNUS.REX MAGNUS TONITRUS MAGNUS.REX HEROS ka ra ka mi sà REGIO REX",
         # "??? pa VIR ti sa MAGNUS.REX HEROS INFANS ní mu za",
         # "wa tu tá a CORNU ra ti REGIO LIS arha. SPHINX"]
    a = ["MAGNUS.REX MAGNUS-TONITRUS MAGNUS.REX HEROS ka-ra-ka-mi-sà REGIO REX",
         "???-pa-VIR-ti-sa MAGNUS.REX HEROS INFANS-ní-mu-za",
         "wa-tu-tá-a CORNU-ra-ti REGIO LIS arha.-SPHINX"]
    b = [alpha_to_luwian(i) for i in a]
    for i in b:
        print(i)




#! /usr/bin/env python3

""" Lydian converter

The transliteration scheme is as follows

    -----------------------------------------------------------------------
    | a     𐤠 | b,p   𐤡 | g     𐤢 | d     𐤣 | e     𐤤 | v,w   𐤥 | i     𐤦 |
    | y     𐤧 | k     𐤨 | l     𐤩 | m     𐤪 | n     𐤫 | o     𐤬 | r     𐤭 |
    | S,ś   𐤮 | t     𐤯 | u     𐤰 | f     𐤱 | q     𐤲 | s,sh  𐤳 | T     𐤴 |
    | ã     𐤵 | A     𐤵 | ẽ     𐤶 | E     𐤶 | L     𐤷 | N     𐤸 | c     𐤹 |
    | .      |         |         |         |         |         |         |
    -----------------------------------------------------------------------

"""

def alpha_to_lydian(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Lydian Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("a", "𐤠")
    output = output.replace("b", "𐤡")
    output = output.replace("p", "𐤡")
    output = output.replace("g", "𐤢")
    output = output.replace("d", "𐤣")
    output = output.replace("e", "𐤤")
    output = output.replace("v", "𐤥")
    output = output.replace("w", "𐤥")
    output = output.replace("i", "𐤦")
    output = output.replace("y", "𐤧")
    output = output.replace("k", "𐤨")
    output = output.replace("l", "𐤩")
    output = output.replace("m", "𐤪")
    output = output.replace("n", "𐤫")
    output = output.replace("o", "𐤬")
    output = output.replace("r", "𐤭")
    output = output.replace("S", "𐤮")
    output = output.replace("ś", "𐤮")
    output = output.replace("t", "𐤯")
    output = output.replace("u", "𐤰")
    output = output.replace("f", "𐤱")
    output = output.replace("q", "𐤲")
    output = output.replace("s", "𐤳")
    output = output.replace("sh","𐤳")
    output = output.replace("T", "𐤴")
    output = output.replace("ã", "𐤵")
    output = output.replace("A", "𐤵")
    output = output.replace("ẽ", "𐤶")
    output = output.replace("E", "𐤶")
    output = output.replace("L", "𐤷")
    output = output.replace("N", "𐤸")
    output = output.replace("c", "𐤹")
    output = output.replace(".", "")

    return output


if __name__ == "__main__":
       a = """
       oraL islL bakillL est mrud eśśk 
       """
       b = alpha_to_lydian(a)
       print(b)



#! /usr/bin/env python3

""" Old Persian converter

The transliteration scheme is as follows:

    -----------------------------------------------------------------
    | a    𐎠 | i    𐎡 | u    𐎢 | k    𐎣 | ku   𐎤 | x    𐎧 | xi   𐎧  |
    | xu   𐎧 | g    𐎥 | gu   𐎦 | c    𐎨 | ç    𐏂 | j    𐎩 | ji   𐎪  |
    | t    𐎫 | ti   𐎫 | tu   𐎬 | th   𐎰 | d    𐎭 | di   𐎮 | du   𐎯  |
    | p    𐎱 | f    𐎳 | b    𐎲 | n    𐎴 | ni   𐎴 | nu   𐎵 | m    𐎶  |
    | mi   𐎷 | mu   𐎸 | y    𐎹 | v    𐎺 | vi   𐎻 | r    𐎼 | ri   𐎽  |
    | l    𐎾 | s    𐎿 | z    𐏀 | š    𐏁 | sh   𐏁 | h    𐏃           |
    -----------------------------------------------------------------

    ----------------------------------------------------
    | ahuramazda1  𐏈 | ahuramazda2  𐏉 | ahuramazda3 𐏊  |
    | xshayathia   𐏋 | dahyaus1     𐏌 | dahyaus2    𐏌  |
    | baga         𐏎 | bumis        𐏏 |                |
    ----------------------------------------------------

"""

def alpha_to_oldpersian(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Old Persian Script
    """
    # print(input.translate(script))

    output = input.replace("-","")
    output = output.replace("ahuramazda1", "𐏈")
    output = output.replace("ahuramazda2", "𐏉")
    output = output.replace("ahuramazda3", "𐏊")
    output = output.replace("xshayathia", "𐏋")
    output = output.replace("dahyaus1", "𐏌")
    output = output.replace("dahyaus2", "𐏌")
    output = output.replace("baga", "𐏎")
    output = output.replace("bumis", "𐏏")
    output = output.replace("mi", "𐎷")
    output = output.replace("mu", "𐎸")
    output = output.replace("ku", "𐎤")
    output = output.replace("xi", "𐎧")
    output = output.replace("gu", "𐎦")
    output = output.replace("xu", "𐎧")
    output = output.replace("ji", "𐎪")
    output = output.replace("ti", "𐎫")
    output = output.replace("tu", "𐎬")
    output = output.replace("th", "𐎰")
    output = output.replace("di", "𐎮")
    output = output.replace("du", "𐎯")
    output = output.replace("ni", "𐎴")
    output = output.replace("nu", "𐎵")
    output = output.replace("vi", "𐎻")
    output = output.replace("ri", "𐎽")
    output = output.replace("sh", "𐏁")
    output = output.replace("a", "𐎠")
    output = output.replace("i", "𐎡")
    output = output.replace("u", "𐎢")
    output = output.replace("k", "𐎣")
    output = output.replace("x", "𐎧")
    output = output.replace("g", "𐎥")
    output = output.replace("c", "𐎨")
    output = output.replace("ç", "𐏂")
    output = output.replace("j", "𐎩")
    output = output.replace("t", "𐎫")
    output = output.replace("d", "𐎭")
    output = output.replace("p", "𐎱")
    output = output.replace("f", "𐎳")
    output = output.replace("b", "𐎲")
    output = output.replace("n", "𐎴")
    output = output.replace("m", "𐎶")
    output = output.replace("y", "𐎹")
    output = output.replace("v", "𐎺")
    output = output.replace("r", "𐎼")
    output = output.replace("l", "𐎾")
    output = output.replace("s", "𐎿")
    output = output.replace("z", "𐏀")
    output = output.replace("š", "𐏁")
    output = output.replace("h", "𐏃")

    return output


if __name__ == "__main__":
       a = """
       ahuramazda1
       """
       b = alpha_to_oldpersian(a)
       print(b)



#! /usr/bin/env python3

""" Avestan script converter

If no optional argument is passed, the script converts to Avestan Script.
Else, you can pass the optional argument translit for converting to
latin script with macrons and diacritics for Avestan.
The typing scheme is as follows:

--------------------------------------------------------------------------
| a   a   𐬀  | A   ā   𐬁  ||  á   å  𐬂  | Á ā̊  𐬃  || ã  ą  𐬄 | ãã  ą̇   𐬅 |
| æ   ə   𐬆  | Æ   ə̄   𐬇  ||  e   e  𐬈  | E ē  𐬉  || o  o  𐬊 | O   ō   𐬋 |
| i   i   𐬌  | I   ī   𐬍  ||  u   u  𐬎  | U ū  𐬏  || k  k  𐬐 | x   x   𐬑 |
| X   x́   𐬒  | xw  x   𐬓  ||  g   g  𐬔  | G ġ  𐬕  || gh γ  𐬖 | c   č   𐬗 |
| j   ǰ   𐬘  | t   t   𐬙  ||  th  ϑ  𐬚  | d d  𐬛  || dh δ  𐬜 | T   t̰   𐬝 |
| p   p   𐬞  | f   f   𐬟  ||  b   b  𐬠  | B β  𐬡  || ng ŋ  𐬢 | ngh ŋ́   𐬣 |
| ngw ŋ   𐬤  | n   n   𐬥  ||  ñ   ń  𐬦  | N ṇ  𐬧  || m  m  𐬨 | M   m̨   𐬩 |
| Y   ẏ   𐬪  | y   y   𐬫  ||  v   v  𐬬  | r r  𐬭  || s  s  𐬯 | z   z   𐬰 |
| sh  š   𐬱  | zh  ž   𐬲  ||  shy š́  𐬳  | S ṣ̌  𐬴  || h  h  𐬵 |           |
--------------------------------------------------------------------------

"""

def alpha_to_avestan(input):
    """ Converts text in Latin Alphabet to Avestan Script

    Each syllable should be separated by a sing dash, each word by a space.

    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Avestan Script

    Usage
    -----
    
    > alpha_to_avestan("<++>")
    + 

    """
    # print(input.translate(script))

    output = input
    output = output.replace("A", "𐬁")
    output = output.replace("aa", "𐬀")
    output = output.replace("a", "𐬀")
    output = output.replace("Á", "𐬃")
    output = output.replace("áá", "𐬂")
    output = output.replace("á", "𐬂")
    output = output.replace("ãã", "𐬅")
    output = output.replace("ã", "𐬄")
    output = output.replace("ææ", "𐬆")
    output = output.replace("æ", "𐬆")
    output = output.replace("Æ", "𐬇")
    output = output.replace("ee", "𐬈")
    output = output.replace("e", "𐬈")
    output = output.replace("E", "𐬉")
    output = output.replace("oo", "𐬊")
    output = output.replace("o", "𐬊")
    output = output.replace("O", "𐬋")
    output = output.replace("i", "𐬌")
    output = output.replace("I", "𐬍")
    output = output.replace("u", "𐬎")
    output = output.replace("U", "𐬏")
    output = output.replace("k", "𐬐")
    output = output.replace("X", "𐬒")
    output = output.replace("xw", "𐬓")
    output = output.replace("x", "𐬑")
    output = output.replace("c", "𐬗")
    output = output.replace("j", "𐬘")
    output = output.replace("th", "𐬚")
    output = output.replace("t", "𐬙")
    output = output.replace("dh", "𐬜")
    output = output.replace("d", "𐬛")
    output = output.replace("T", "𐬝")
    output = output.replace("p", "𐬞")
    output = output.replace("f", "𐬟")
    output = output.replace("b", "𐬠")
    output = output.replace("B", "𐬡")
    output = output.replace("ngh", "𐬣")
    output = output.replace("ngw", "𐬤")
    output = output.replace("ng", "𐬢")
    output = output.replace("gh", "𐬖")
    output = output.replace("g", "𐬔")
    output = output.replace("G", "𐬕")
    output = output.replace("ñ", "𐬦")
    output = output.replace("n", "𐬥")
    output = output.replace("N", "𐬧")
    output = output.replace("m", "𐬨")
    output = output.replace("M", "𐬩")
    output = output.replace("Y", "𐬪")
    output = output.replace("y", "𐬫")
    output = output.replace("v", "𐬬")
    output = output.replace("r", "𐬭")
    output = output.replace("sh", "𐬱")
    output = output.replace("zh", "𐬲")
    output = output.replace("shy", "𐬳")
    output = output.replace("S", "𐬴")
    output = output.replace("s", "𐬯")
    output = output.replace("z", "𐬰")
    output = output.replace("h", "𐬵")

    return output


def alpha_to_avestan_trans(input):
    output = input
    output = output.replace("A", "ā")
    output = output.replace("aa", "ā")
    output = output.replace("Á", "ā̊")
    output = output.replace("áá", "ā̊")
    output = output.replace("á", "å")
    output = output.replace("Ã", "ą̇")
    output = output.replace("ãã", "ą̇")
    output = output.replace("ã", "ą")
    output = output.replace("ææ", "ə̄")
    output = output.replace("æ", "ə")
    output = output.replace("Æ", "ə̄")
    output = output.replace("ee", "ē")
    output = output.replace("E", "ē")
    output = output.replace("oo", "ō")
    output = output.replace("O", "ō")
    output = output.replace("I", "ī")
    output = output.replace("U", "ū")
    output = output.replace("X", "x́")
    output = output.replace("xw", "xᵛ")
    output = output.replace("c", "č")
    output = output.replace("j", "ǰ")
    output = output.replace("th", "ϑ")
    output = output.replace("dh", "δ")
    output = output.replace("T", "t̰")
    output = output.replace("B", "β")
    output = output.replace("ngh", "ŋ́")
    output = output.replace("ngw", "ŋᵛ")
    output = output.replace("ng", "ŋ")
    output = output.replace("gh", "γ")
    output = output.replace("G", "ġ")
    output = output.replace("ñ", "ń")
    output = output.replace("N", "ṇ")
    output = output.replace("m", "m")
    output = output.replace("M", "m̨")
    output = output.replace("Y", "ẏ")
    output = output.replace("sh", "š")
    output = output.replace("zh", "ž")
    output = output.replace("shy", "š́")
    output = output.replace("S", "ṣ̌")
    

    return output


if __name__ == "__main__":
       a = """
       paoiriiáá dasa xshpanoo
       spitama zarathushtra
       tishtrioo raeeuuáá xwarænangwháá
       """
       b = alpha_to_avestan(a)
       print(b)



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
        name="pieoffice",
        description="A terminal based script converter for ancient (Proto-)Indo-European languages.",
        url="https://gitlab.com/caiogeraldes/pieoffice",
        long_description=long_description,
        long_description_content_type="text/markdown",
        version="1.0.2",
        license="MIT",
        author="Caio Geraldes",
        author_email="caiogeraldes@protonmail.com",
        packages=find_packages(),
        entry_points={
        'console_scripts': [
           'pieoffice=pieoffice.__main__:main'
            ]
        },
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
        python_requires=">=3.6",
)



#! /usr/bin/env python3

""" Carian converter

The transliteration scheme is as follows

    -------------------------------------------------------------------
    | a      𐊠 | b      𐊡 | d      𐊢 | l      𐊣 | y      𐊤 | y2     𐋐 |
    | r      𐊥 | L      𐊦 | L2     𐋎 | A2     𐊧 | q      𐊨 | b      𐊩 |
    | m      𐊪 | o      𐊫 | D2     𐊬 | t      𐊭 | sh     𐊮 | sh2    𐊯 |
    | s      𐊰 | 18     𐊱 | u      𐊲 | N      𐊳 | c      𐊴 | n      𐊵 |
    | T2     𐊶 | p      𐊷 | 's,ś   𐊸 | i      𐊹 | e      𐊺 | ý,'y   𐊻 |
    | k      𐊼 | k2     𐊽 | dh     𐊾 | w      𐊿 | G      𐋀 | G2     𐋁 |
    | z2     𐋂 | z      𐋃 | ng     𐋄 | j      𐋅 | 39     𐋆 | T      𐋇 |
    | y3     𐋈 | r2     𐋉 | mb     𐋊 | mb2    𐋋 | mb3    𐋌 | mb4    𐋍 |
    | e2     𐋏 |                                                      |
    -------------------------------------------------------------------

"""

def alpha_to_carian(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Carian Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("a", "𐊠")
    output = output.replace("e2", "𐋏")
    output = output.replace("r2", "𐋉")
    output = output.replace("z2", "𐋂")
    output = output.replace("b", "𐊡")
    output = output.replace("d", "𐊢")
    output = output.replace("l", "𐊣")
    output = output.replace("y3", "𐋈")
    output = output.replace("y2", "𐋐")
    output = output.replace("ý", "𐊻")
    output = output.replace("'y", "𐊻")
    output = output.replace("y", "𐊤")
    output = output.replace("r", "𐊥")
    output = output.replace("L2", "𐋎")
    output = output.replace("L", "𐊦")
    output = output.replace("A2", "𐊧")
    output = output.replace("q", "𐊨")
    output = output.replace("b", "𐊩")
    output = output.replace("m", "𐊪")
    output = output.replace("o", "𐊫")
    output = output.replace("D2", "𐊬")
    output = output.replace("t", "𐊭")
    output = output.replace("sh2", "𐊯")
    output = output.replace("sh", "𐊮")
    output = output.replace("'s", "𐊸")
    output = output.replace("ś", "𐊸")
    output = output.replace("s", "𐊰")
    output = output.replace("18", "𐊱")
    output = output.replace("u", "𐊲")
    output = output.replace("N", "𐊳")
    output = output.replace("c", "𐊴")
    output = output.replace("n", "𐊵")
    output = output.replace("T2", "𐊶")
    output = output.replace("p", "𐊷")
    output = output.replace("i", "𐊹")
    output = output.replace("e", "𐊺")
    output = output.replace("k2", "𐊽")
    output = output.replace("k", "𐊼")
    output = output.replace("dh", "𐊾")
    output = output.replace("w", "𐊿")
    output = output.replace("G2", "𐋁")
    output = output.replace("G", "𐋀")
    output = output.replace("z", "𐋃")
    output = output.replace("ng", "𐋄")
    output = output.replace("j", "𐋅")
    output = output.replace("39", "𐋆")
    output = output.replace("T", "𐋇")
    output = output.replace("mb2", "𐋋")
    output = output.replace("mb3", "𐋌")
    output = output.replace("mb4", "𐋍")
    output = output.replace("mb", "𐋊")

    return output


if __name__ == "__main__":
       a = """
       esbe
       """
       b = alpha_to_carian(a)
       print(b)



#! /usr/bin/env python3

""" Lycian converter

The transliteration scheme is as follows

    -----------------------------------------------------------------
    | a    𐊀 |   b    𐊂 |   g    𐊄 |   d    𐊅 |   i    𐊆 |   w    𐊇 |
    | z    𐊈 |   h    𐊛 |   th   𐊉 |   j    𐊊 |   y    𐊊 |   k    𐊋 |
    | l    𐊍 |   m    𐊎 |   n    𐊏 |   u    𐊒 |   p    𐊓 |   k    𐊔 |
    | r    𐊕 |   s    𐊖 |   t    𐊗 |   e    𐊁 |   ã    𐊙 |   ẽ    𐊚 |
    | M    𐊐 |   N    𐊑 |   T    𐊘 |   q    𐊌 |   B    𐊃 |   x    𐊜 |
    -----------------------------------------------------------------

"""

def alpha_to_lycian(input):
    """ 
    Parameters
    ----------
    input : str
        Text input with syllables separated by dashes and words by spaces.

    Returns
    -------
    output : str
        Transliterated text in Lycian Script
    """
    # print(input.translate(script))

    output = input
    output = output.replace("a", "𐊀")
    output = output.replace("b", "𐊂")
    output = output.replace("g", "𐊄")
    output = output.replace("d", "𐊅")
    output = output.replace("i", "𐊆")
    output = output.replace("w", "𐊇")
    output = output.replace("z", "𐊈")
    output = output.replace("h", "𐊛")
    output = output.replace("j", "𐊊")
    output = output.replace("y", "𐊊")
    output = output.replace("k", "𐊋")
    output = output.replace("l", "𐊍")
    output = output.replace("m", "𐊎")
    output = output.replace("n", "𐊏")
    output = output.replace("u", "𐊒")
    output = output.replace("p", "𐊓")
    output = output.replace("k", "𐊔")
    output = output.replace("r", "𐊕")
    output = output.replace("s", "𐊖")
    output = output.replace("t", "𐊗")
    output = output.replace("e", "𐊁")
    output = output.replace("ã", "𐊙")
    output = output.replace("ẽ", "𐊚")
    output = output.replace("M", "𐊐")
    output = output.replace("N", "𐊑")
    output = output.replace("T", "𐊘")
    output = output.replace("q", "𐊌")
    output = output.replace("B", "𐊃")
    output = output.replace("x", "𐊜")
    output = output.replace("th","𐊉")

    return output


if __name__ == "__main__":
       a = """
       esbe
       """
       b = alpha_to_lycian(a)
       print(b)
